'use strict';
/*jshint expr: true*/
require('should');

var youtube = require('../utils/youtube.js');

describe('Youtube', function() {
  let links = {
    'https://www.youtube.com/watch?v=QH2-TGUlwu4': true,
    'http://www.youtube.com/watch?v=QH2-TGUlwu4': true,
    'https://youtu.be/QH2-TGUlwu4': true,
    'https://youtu.be/QH2-TGUlwu4?t=3m30s': true,
    'https://www.youtube.com/watch?t=3m30s&v=QH2-TGUlwu4': true,
    'https://www.youtube.cz/watch?t=3m30s&v=QH2-TGUlwu4': true,
    'https://www.youtube.com/watch?app=desktop&gl=CZ&v=QH2-TGUlwu4&hl=cs&v=cTa1Q2mBeJE': true,
    'https://www.youtube.com/': false,
    'https://www.youtube.com/channel/UCzNxmbk_LA1jXvYgivCCkpw': false,
    'youtube.png': false
  }
  function testLink(link, val) {
    it('isVideo '+link+' => '+val,function() {
      youtube.isVideo(link).should.be.equal(val);
    })
  }
  for(let link in links) {
    if(!links.hasOwnProperty(link)) continue;
    testLink(link, links[link]);
  }

  it('info https://youtu.be/wZZ7oFKsKzY?t=3h30m30s', function() {
    var info = youtube.info('https://youtu.be/wZZ7oFKsKzY?t=3h30m30s');
    info.should.be.object;
    info.time.should.be.eql(3*3600+30*60+30);
    info.videoid.should.be.eql('wZZ7oFKsKzY');
  })

  it('info https://youtu.be/QH2-TGUlwu4', function() {
    var info = youtube.info('https://youtu.be/QH2-TGUlwu4');
    info.should.be.object;
    info.time.should.be.eql(0);
    info.videoid.should.be.eql('QH2-TGUlwu4');
  })

  it('info https://www.youtube.com/watch?t=3m30s&v=QH2-TGUlwu4', function() {
    var info = youtube.info('https://www.youtube.com/watch?t=3m30s&v=QH2-TGUlwu4');
    info.should.be.object;
    info.time.should.be.eql(3*60+30);
    info.videoid.should.be.eql('QH2-TGUlwu4');
  })
})
